@@ -10,10 +10,12 @@ def i_retrieve_a_list_of_remote_models(step, tag):
     world.list_of_models = [world.api.get_model(model['resource']) for model in
                             world.api.list_models(query_string="tags__in=%s" % tag)['objects']]
 
+
 @step(r'I create a local model')
 def i_create_a_local_model(step):
     world.local_model = Model(world.model)
 
+
 @step(r'I create a local prediction for "(.*)"')
 def i_create_a_local_prediction(step, data=None):
     if data is None:
@@ -21,6 +23,16 @@ def i_create_a_local_prediction(step, data=None):
     data = json.loads(data)
     world.local_prediction = world.local_model.predict(data)
 
+
+@step(r'I create a proportional missing strategy local prediction for "(.*)"')
+def i_create_a_proportional_local_prediction(step, data=None):
+    if data is None:
+        data = "{}"
+    data = json.loads(data)
+    world.local_prediction = world.local_model.predict(
+        data, with_confidence=True, missing_strategy=1)
+
+
 @step(r'I create a prediction from a multi model for "(.*)"')
 def i_create_a_prediction_from_a_multi_model(step, data=None):
     if data is None:
@@ -28,9 +40,34 @@ def i_create_a_prediction_from_a_multi_model(step, data=None):
     data = json.loads(data)
     world.local_prediction = world.local_model.predict(data)
 
+
 @step(r'the local prediction is "(.*)"')
 def the_local_prediction_is(step, prediction):
-    assert world.local_prediction == prediction
+    if isinstance(world.local_prediction, list):
+        local_prediction = world.local_prediction[0]
+    else:
+        local_prediction = world.local_prediction
+    try:
+        local_model = world.local_model
+        if local_model.tree.regression:
+            local_prediction = round(float(local_prediction), 4)
+            prediction = round(float(prediction), 4)
+    except:
+        local_model = world.local_ensemble.multi_model.models[0]
+        if local_model.tree.regression:
+            local_prediction = round(float(local_prediction), 4)
+            prediction = round(float(prediction), 4)
+
+    assert local_prediction == prediction
+
+
+@step(r'the confidence for the local prediction is "(.*)"')
+def the_local_prediction_confidence_is(step, confidence):
+    local_confidence = world.local_prediction[1]
+    local_confidence = round(float(local_confidence), 4)
+    confidence = round(float(confidence), 4)
+    assert local_confidence == confidence
+
 
 @step(r'I create a local multi model')
 def i_create_a_local_multi_model(step):
